Tinkerer-Localpost
==================

.. image:: https://travis-ci.org/gisraptor/tinkerer-localpost.png
    :target: https://travis-ci.org/gisraptor/tinkerer-localpost/

What is Tinkerer-Localpost?
---------------------------

`Tinkerer-Localpost <http://github.com/gisraptor/tinkerer-localpost>`_ is an
addon for `Tinkerer <http://tinkerer.me>`_ that makes it easy to see your blog before you publish it.

Tinkerer-Localpost provides the ability to see your site as it would appear on
the Web from the privacy of your own computer. Use it to review your posts and
pages, check your RSS feed, build custom themes and customize your blog to your
heart's content.

Remember, before you post, always http://localhost.

Tinkerer-Localpost requires Tinkerer to function properly.

How do I use Tinkerer-Localpost?
--------------------------------

Get Tinkerer-Localpost::

    pip install tinkerer-localpost

From within your Tinkerer blog, run::

    localpost

.. See the documentation for more details.
